@@ -632,7 +632,7 @@ def _ReOrderedSites(sites: Tuple[array_t, ...]) -> Tuple[array_t, ...]:
 
     sites_as_array = np_.transpose(np_.array(sites))
     reordered_coords = [np_.array([sites[idx][0] for idx in range(sites.__len__())])]
-    unvisited_slc = np_.ones(n_sites, dtype=np_.bool)
+    unvisited_slc = np_.ones(n_sites, dtype=np_.bool_)
     unvisited_slc[0] = False
     unvisited_sites = None
     end_point = None
