@@ -218,11 +218,14 @@ class skl_graph_t(nx_.MultiGraph):
             return True
         #
         elif (tmap[tmap != background_label] == 2).all():
+            # The tmap represents a self loop
             loop_slc = np_.nonzero(tmap == 2)
 
+            # Takes the first pixel to serve as a node, and the rest for the self-loop edge
+            #
             # 0:1 makes sites elements array_t's (instead of numpy numbers), which is necessary for
             # nd_.branch_node_t.WithCentroidAndSites, but requires to squeeze the centroid.
-            sites = tuple(loop_slc[idx][0:1] for idx in range(loop_slc.__len__()))
+            sites = tuple(per_dim[0:1] for per_dim in loop_slc)
             centroid = np_.array(sites, dtype=np_.float64).squeeze()
             node = nd_.branch_node_t.WithCentroidAndSites(
                 centroid, sites=sites, width_map=width_map
@@ -231,8 +234,7 @@ class skl_graph_t(nx_.MultiGraph):
 
             n_unique_sites = loop_slc[0].__len__()
             sites = tuple(
-                loop_slc[idx][list(range(n_unique_sites)) + [0]]
-                for idx in range(loop_slc.__len__())
+                per_dim[list(range(n_unique_sites)) + [0]] for per_dim in loop_slc
             )
             adjacent_node_uids = (node.uid, node.uid)
             edge = dg_.edge_t.NewWithDetails(
@@ -558,7 +560,6 @@ class skl_graph_t(nx_.MultiGraph):
             self,
             ax=axes,
             pos=positions_as_dict,
-            with_labels=True,
             node_color=node_colors,
             font_size=font_size,
             width=width,
